@@ -24,19 +24,31 @@ export PATH="${PATH}:${TOOLCHAIN_DIR}/bin"
 
 export SODIUM_ANDROID_PREFIX=${SODIUM_ANDROID_PREFIX:-/tmp/libsodium-android-${TARGET_ARCH}}
 export CPPFLAGS="$CPPFLAGS -I${SODIUM_ANDROID_PREFIX}/include"
-export CPPFLAGS="$CPPFLAGS -DUSE_ONLY_PORTABLE_IMPLEMENTATIONS=1"
 export LDFLAGS="$LDFLAGS -L${SODIUM_ANDROID_PREFIX}/lib"
 
 rm -rf "${TOOLCHAIN_DIR}" "${PREFIX}"
 
-bash $MAKE_TOOLCHAIN --platform="${NDK_PLATFORM:-android-18}" \
-                --arch="$ARCH" \
-                --install-dir="$TOOLCHAIN_DIR" && \
-./configure --host="${HOST_COMPILER}" \
-            --with-sysroot="${TOOLCHAIN_DIR}/sysroot" \
-            --prefix="${PREFIX}" \
-            --disable-soname-versions \
-            --disable-shared && \
+bash $MAKE_TOOLCHAIN --platform="${NDK_PLATFORM:-android-16}" \
+    --arch="$ARCH" --install-dir="$TOOLCHAIN_DIR" && \
+./configure \
+    --bindir="${PREFIX}/system/xbin" \
+    --datadir="${PREFIX}/system/etc" \
+    --disable-soname-versions \
+    --disable-plugins \
+    --enable-relaxed-plugins-permissions \
+    --host="${HOST_COMPILER}" \
+    --prefix="${PREFIX}/system" \
+    --sbindir="${PREFIX}/system/xbin" \
+    --sysconfdir="${PREFIX}/system/etc" \
+    --with-sysroot="${TOOLCHAIN_DIR}/sysroot" && \
 make clean && \
 make -j3 install && \
-echo "dnscrypt-proxy has been installed into $PREFIX"
+rm -fr "${PREFIX}/system/include" "${PREFIX}/system/share" "${PREFIX}/system/man" && \
+mkdir -p "${PREFIX}/system/lib" && \
+cp "${SODIUM_ANDROID_PREFIX}/lib/libsodium.so" "${PREFIX}/system/lib" && \
+(cd dist-build/android-files && tar cpf - *) | (cd "$PREFIX" && tar xpvf -) &&
+(cd "$PREFIX"; zip -9 -r "${PREFIX}.zip" *) && \
+echo "dnscrypt-proxy has been installed here:" && \
+echo "${PREFIX}" && \
+echo "The dnscrypt-proxy ZIP file has been placed here:" && \
+echo "${PREFIX}.zip"
