@@ -24,6 +24,7 @@
 #include "plugin_support.h"
 #include "plugin_support_p.h"
 #include "queue.h"
+#include "utils.h"
 
 int
 plugin_support_add_option(DCPluginSupport * const dcps, char * const arg)
@@ -210,30 +211,21 @@ plugin_support_expand_plugin_file(const char * const plugin_file)
     if (strncmp(plugin_file, PLUGINS_ROOT, plugins_root_len) == 0) {
         return strdup(plugin_file);
     }
-#else
-# ifdef _WIN32
-    const char *chr_column;
-    const char *chr_pathsep;
-
-    if (((chr_pathsep = strchr(plugin_file, '/')) != NULL ||
-         (chr_pathsep = strchr(plugin_file, '\\')) != NULL) &&
-        (chr_pathsep == plugin_file ||
-            ((chr_column = strchr(plugin_file, ':')) != NULL &&
-                chr_column - plugin_file < chr_pathsep - plugin_file))) {
-        return strdup(plugin_file);
-    }
-# else
+#elif !defined(_WIN32)
     if (*plugin_file == '/') {
         return strdup(plugin_file);
     }
-# endif
 #endif
 #ifdef _WIN32
-    assert(PLUGINS_ROOT[plugins_root_len - (size_t) 1U] == '/' ||
-           PLUGINS_ROOT[plugins_root_len - (size_t) 1U] == '\\');
+    if ((expanded_plugin_file =
+         path_from_app_folder(plugin_file)) == NULL) {
+        logger_noformat(NULL, LOG_EMERG, "Out of memory");
+        exit(1);
+    }
+    (void) plugin_file_len;
+    (void) sizeof_expanded_plugin_file;
 #else
     assert(PLUGINS_ROOT[plugins_root_len - (size_t) 1U] == '/');
-#endif
     plugin_file_len = strlen(plugin_file);
     assert(SIZE_MAX - plugins_root_len > plugin_file_len);
     sizeof_expanded_plugin_file = plugins_root_len + plugin_file_len + 1U;
@@ -243,6 +235,7 @@ plugin_support_expand_plugin_file(const char * const plugin_file)
     memcpy(expanded_plugin_file, PLUGINS_ROOT, plugins_root_len);
     memcpy(expanded_plugin_file + plugins_root_len, plugin_file,
            plugin_file_len + 1U);
+#endif
 
     return expanded_plugin_file;
 }
