@@ -242,7 +242,7 @@ windows_service_registry_write_string(const char * const key,
                        NULL, &hk, NULL) != ERROR_SUCCESS) {
         return -1;
     }
-    if (RegSetValueEx(hk, key, NULL, REG_SZ, (const BYTE *) value,
+    if (RegSetValueEx(hk, key, (DWORD) 0, REG_SZ, (const BYTE *) value,
                       (DWORD) value_len) != ERROR_SUCCESS) {
         ret = -1;
     }
@@ -301,13 +301,15 @@ windows_build_command_line_from_registry(int * const argc_p,
     }
     if (windows_service_registry_read_dword
         ("EDNSPayloadSize", &dword_value) == 0) {
-        snprintf(dword_string, sizeof dword_string, "%ld", (long) dword_value);
+        evutil_snprintf(dword_string, sizeof dword_string, "%ld",
+                        (long) dword_value);
         err += cmdline_add_option(argc_p, argv_p, "--edns-payload-size");
         err += cmdline_add_option(argc_p, argv_p, dword_string);
     }
     if (windows_service_registry_read_dword
         ("MaxActiveRequests", &dword_value) == 0) {
-        snprintf(dword_string, sizeof dword_string, "%ld", (long) dword_value);
+        evutil_snprintf(dword_string, sizeof dword_string, "%ld",
+                        (long) dword_value);
         err += cmdline_add_option(argc_p, argv_p, "--max-active-requests");
         err += cmdline_add_option(argc_p, argv_p, dword_string);
     }
@@ -319,6 +321,12 @@ windows_build_command_line_from_registry(int * const argc_p,
         ("EphemeralKeys", &dword_value) == 0 && dword_value > (DWORD) 0) {
         err += cmdline_add_option(argc_p, argv_p, "--ephemeral-keys");
     }
+    if (windows_service_registry_read_string
+        ("ClientKeyFile", &string_value) == 0) {
+        err += cmdline_add_option(argc_p, argv_p, "--client-key");
+        err += cmdline_add_option(argc_p, argv_p, string_value);
+        free(string_value);
+    }
     windows_service_registry_read_multi_sz
         ("Plugins", & (WindowsServiceParseMultiSzCb) {
             .cb = windows_service_parse_multi_sz_cb,
@@ -415,15 +423,19 @@ windows_registry_install(ProxyContext * const proxy_context)
 {
     if (proxy_context->resolvers_list != NULL) {
         windows_service_registry_write_string("ResolversList",
-                                             proxy_context->resolvers_list);
+                                              proxy_context->resolvers_list);
     }
     if (proxy_context->resolver_name != NULL) {
         windows_service_registry_write_string("ResolverName",
-                                             proxy_context->resolver_name);
+                                              proxy_context->resolver_name);
     }
     if (proxy_context->local_ip != NULL) {
         windows_service_registry_write_string("LocalAddress",
-                                             proxy_context->local_ip);
+                                              proxy_context->local_ip);
+    }
+    if (proxy_context->client_key_file != NULL) {
+        windows_service_registry_write_string("ClientKeyFile",
+                                              proxy_context->client_key_file);
     }
     return 0;
 }
